@@ -95,7 +95,11 @@ PA_SUBSCRIPTION_EVENT_CHANGE = 0x0010
 PA_SUBSCRIPTION_EVENT_REMOVE = 0x0020
 PA_SUBSCRIPTION_EVENT_TYPE_MASK = 0x0030
 
-PA_SAMPLE_FLOAT32BE = 5
+PA_SAMPLE_FLOAT32LE = 5
+PA_SAMPLE_FLOAT32BE = 6
+PA_SAMPLE_FLOAT32NE = dict(
+	little=PA_SAMPLE_FLOAT32LE,
+	big=PA_SAMPLE_FLOAT32BE )[sys.byteorder]
 
 PA_STREAM_DONT_MOVE = 0x0200
 PA_STREAM_PEAK_DETECT = 0x0800
@@ -148,7 +152,7 @@ class PA_SAMPLE_SPEC(Structure):
 	_fields_ = [
 		('format', c_int),
 		('rate', c_uint32),
-		('channels', c_uint32)
+		('channels', c_uint8)
 	]
 
 class PA_CHANNEL_MAP(Structure):
